@@ -1,8 +1,8 @@
-import asyncio
 import os
 from copy import deepcopy
 from typing import Dict, List, Text
 
+import sqlalchemy
 from gino import Gino
 from sanic import Blueprint, Sanic, response, router
 from sanic_jwt import Initialize
@@ -11,19 +11,18 @@ from gino_admin import config
 from gino_admin.auth import authenticate
 from gino_admin.history import add_history_model
 from gino_admin.routes import rest
-from gino_admin.users import add_users_model
+from gino_admin.types import types_map
 from gino_admin.utils import (GinoAdminError, HashColumn, get_table_name,
-                              logger, parse_db_uri, types_map)
+                              logger, parse_db_uri)
 
 cfg = config.cfg
 
 
 admin = Blueprint("admin", url_prefix=cfg.route)
 
-STATIC_FOLDER = os.path.join(os.path.dirname(os.path.abspath(__file__)), "static")
 
-admin.static("/static", STATIC_FOLDER)
-admin.static("/favicon.ico", os.path.join(STATIC_FOLDER, "favicon.ico"))
+admin.static("/static", config.STATIC_FOLDER)
+admin.static("/favicon.ico", os.path.join(config.STATIC_FOLDER, "favicon.ico"))
 
 
 def extract_column_data(model_id: Text) -> Dict:
@@ -54,6 +53,7 @@ def extract_column_data(model_id: Text) -> Dict:
             "primary": column.primary_key,
             "foreign_keys": column.foreign_keys,
             "db_type": column.type,
+            "sequence": isinstance(column.default, sqlalchemy.sql.schema.Sequence),
         }
     required = [
         key
@@ -82,15 +82,15 @@ def extract_column_data(model_id: Text) -> Dict:
         "columns_names": list(columns_data.keys()),
         "hashed_indexes": hashed_indexes,
         "foreign_keys": foreign_keys,
-        "identity": primary_keys if primary_keys else unique_keys,
+        "identity": primary_keys,
     }
     return table_details
 
 
 def extract_models_metadata(db: Gino, db_models: List) -> None:
     """ extract required data about DB Models """
-    db_models.append(cfg.users_model)
-    cfg.models = {model.__tablename__: {"model": model} for model in db_models}
+    cfg.user_models = {model.__tablename__: {"model": model} for model in db_models}
+    cfg.models.update(cfg.user_models)
     cfg.app.db = db
 
     for model_id in cfg.models:
@@ -105,8 +105,8 @@ def add_admin_panel(app: Sanic, db: Gino, db_models: List, **config_settings):
         del config_settings["config"]
     if "custom_hash_method" in config_settings:
         logger.warning(
-            f"'custom_hash_method' will be depricated in version 0.1.0. "
-            f" Please use 'hash_method' instead"
+            "'custom_hash_method' will be depricated in version 0.1.0. "
+            " Please use 'hash_method' instead"
         )
         config_settings["hash_method"] = deepcopy(config_settings["custom_hash_method"])
         del config_settings["custom_hash_method"]
@@ -126,12 +126,9 @@ def add_admin_panel(app: Sanic, db: Gino, db_models: List, **config_settings):
     setup_config_from_args(config_settings)
 
     add_history_model(db)
-
-    loop = asyncio.get_event_loop()
-
-    loop.run_until_complete(add_users_model(db, app.config))
-
+    print(cfg.user_models)
     extract_models_metadata(db, db_models)
+
     if config_settings.get("route"):
         old_prefix = admin.url_prefix
         admin.url_prefix = config_settings["route"]
@@ -192,11 +189,11 @@ def create_admin_app(
 def init_admin_app(host, port, db, db_models, config):
     """ init admin panel app """
     app = Sanic(name="gino_admin")
-        
+
     @app.route("/")
     async def index(request):
         return response.redirect("/admin")
-    
+
     add_admin_panel(app, db, db_models, **config)
 
     return app.run(host=host, port=port, debug=cfg.debug)
