@@ -5,12 +5,11 @@ from sanic.request import Request
 from sanic_jwt.decorators import protected
 
 from gino_admin import config, utils
-from gino_admin.history import write_history_after_response
+from gino_admin.history import log_history_event, write_history_after_response
 from gino_admin.routes.logic import (drop_and_recreate_all_tables,
-                                     insert_data_from_csv_file, upload_from_csv_data)
+                                     insert_data_from_csv_file,
+                                     upload_from_csv_data)
 from gino_admin.utils import get_preset_by_id, logger, read_yaml
-from gino_admin.history import log_history_event
-
 
 cfg = config.cfg
 
@@ -19,8 +18,8 @@ api = Blueprint("api", url_prefix=f"{cfg.route}/api")
 
 @api.middleware("request")
 async def middleware_request(request):
-    request["flash_messages"] = []
-    request["history_action"] = {}
+    request.ctx.flash_messages = []
+    request.ctx.history_action = {}
 
 
 @api.middleware("response")
@@ -56,20 +55,22 @@ async def presets(request: Request):
         await drop_and_recreate_all_tables()
     try:
         for model_id, file_path in preset["files"].items():
-            request["flash_messages"] = []
+            request.ctx.flash_messages = []
             # TODO(ehborisov): handle is_success and errors properly?
             request, is_success = await insert_data_from_csv_file(
                 os.path.join(presets_folder, file_path), model_id.lower(), request
             )
-        logger.debug(str(request["flash_messages"]))
+        logger.debug(str(request.ctx.flash_messages))
         if "drop" in request.json:
             message = "DB was dropped & Preset was success loaded"
         else:
             message = "Preset was loaded"
         result = response.json({"status": f"{message}"}, status=200)
-        log_history_event(request, 
-                          f"Loaded preset {preset['id']}{' with DB drop' if with_drop else ''}",
-                          "system: load_preset")
+        log_history_event(
+            request,
+            f"Loaded preset {preset['id']}{' with DB drop' if with_drop else ''}",
+            "system: load_preset",
+        )
     except FileNotFoundError:
         answer = {"error": f"Wrong file path in Preset {preset['name']}."}
         result = response.json(answer, status=422)
@@ -80,9 +81,13 @@ async def presets(request: Request):
 @protected(api)
 async def drop(request: Request):
     await drop_and_recreate_all_tables()
-    request["history_action"]["log_message"] = "Database has been initialized from scratch"
-    request["history_action"]["object_id"] = "init_db"
-    return response.json({"status": "DB has been dropped. Tables re-created."}, status=200)
+    request.ctx.history_action[
+        "log_message"
+    ] = "Database has been initialized from scratch"
+    request.ctx.history_action["object_id"] = "init_db"
+    return response.json(
+        {"status": "DB has been dropped. Tables re-created."}, status=200
+    )
 
 
 @api.route("/upload_csv", methods=["POST"])
@@ -92,19 +97,33 @@ async def upload_csv(request: Request):
     file_name = utils.secure_filename(upload_file.name)
     model_id = dict(request.query_args).get("model_id")
     if not upload_file or not file_name:
-        return response.json({"error": f"No file is found in the request payload."}, status=422)
-    if not file_name.endswith('.csv') or upload_file.type != "text/csv":
-        return response.json({"error": f"CSV file of text/csv type is expected."}, status=422)
+        return response.json(
+            {"error": "No file is found in the request payload."}, status=422
+        )
+    if not file_name.endswith(".csv") or upload_file.type != "text/csv":
+        return response.json(
+            {"error": "CSV file of text/csv type is expected."}, status=422
+        )
     request, is_success = await upload_from_csv_data(
         upload_file, file_name, request, model_id.lower()
     )
     if is_success:
-        result = response.json({"status": (
-            f"Successfully uploaded {f'model {model_id}' if model_id else 'composite'} data.")}, status=200)
+        result = response.json(
+            {
+                "status": (
+                    f"Successfully uploaded {f'model {model_id}' if model_id else 'composite'} data."
+                )
+            },
+            status=200,
+        )
     else:
-        error = next([m[0] for m in request["flash_messages"] if m[1] == 'error'], None)
+        error = next(
+            [m[0] for m in request.ctx.flash_messages if m[1] == "error"], None
+        )
         if error:
             return response.json({"error": error}, status=422)
         else:
-            return response.json({"error": "Unknown error on csv data upload"}, status=500)
+            return response.json(
+                {"error": "Unknown error on csv data upload"}, status=500
+            )
     return result
