@@ -1,12 +1,11 @@
 import datetime
-import os
+from gino_admin.core import extract_column_data
 from gino_admin import config
-import asyncpg
 
 cfg = config.cfg
 
 
-async def add_users_model(db, config):
+async def add_users_model(db):
     if "gino_admin_users" not in db.tables:
 
         class GinoAdminUser(db.Model):
@@ -20,7 +19,10 @@ async def add_users_model(db, config):
         schema = db.schema + '.' if db.schema else ''
         
         table_name = schema + cfg.admin_users_table_name
-        cfg.users_model = GinoAdminUser
+        cfg.admin_user_model = GinoAdminUser
+        cfg.models['gino_admin_users'] = {"model": GinoAdminUser} 
+        column_details = extract_column_data('gino_admin_users')
+        cfg.models['gino_admin_users'].update(column_details)
         cfg.admin_users_data_columns = [
             column.name for num, column in enumerate(db.tables[table_name].columns)
         ]
